Edit the sitekey file
=======================

The `sitekey file <sitekey.rst>`_ can be edited with a text browzer by the command

.. code-block:: bash

 > passme edit

At first the command to open a text editor is prompted to input. It is stored in **OpenEditor** variable in `configuration <config.rst>`_. System call is invoked as **<OpenEditor> <Name of the sitekey file>** and the editor is invoked.

This function can be used when you want to see the sitekey file or edit it. Be careful not to edit the lines unintentionally, because it may damage your password.

----

Toppage_

.. _Toppage: README.rst
